#ifndef _CONSTANTS_H
#define _CONSTANTS_H 1

#define MAX_NR_CHILDREN 256

#define MAX_PIPE_FDS 4
#define MAX_PERF_FDS 10
#define MAX_EPOLL_FDS 10
#define MAX_EVENTFD_FDS 8
#define NR_SOCKET_FDS 375
#define NR_FILE_FDS 250

#define REGENERATION_POINT 100000

#define MAX_NR_SYSCALL 1024

#endif	/* _CONSTANTS_H */
